@@ -1,5 +1,6 @@
 """Get command"""
 from thabala_cli.commands.utils.api_client import ApiClient
+from thabala_cli.commands.utils.infra_code import VALID_KINDS
 from thabala_cli.commands.utils.profile import get_profile
 
 
@@ -38,7 +39,13 @@ def health(args):
 def infra(args):
     """Get infrastructure as a code of the Thabala account"""
     api_client = ApiClient(get_profile(args))
-    api_client.get_infra(args.kind)
+    api_client.get_infra(args.kind, valid_kinds=VALID_KINDS)
+
+
+def network_policy(args):
+    """Get network policy rules"""
+    api_client = ApiClient(get_profile(args))
+    api_client.get_network_policy(args.limit, args.offset)
 
 
 def version(args):
