@@ -1,3 +1,4 @@
+import json
 import logging
 
 import requests
@@ -33,7 +34,10 @@ class AuthByPassword(AuthBase):
             )
             response.raise_for_status()
         except requests.exceptions.HTTPError as err:
-            raise_thabala_cli_api_exc(err, response.json())
+            try:
+                raise_thabala_cli_api_exc(err, response.json())
+            except json.decoder.JSONDecodeError:
+                raise_thabala_cli_api_exc(err)
         except Exception as err:
             raise_thabala_cli_api_exc(err)
 
